@@ -11,8 +11,15 @@ def runtests(*test_args):
     parent = os.path.dirname(os.path.abspath(__file__))
     sys.path.insert(0, parent)
 
-    from django.test.simple import DjangoTestSuiteRunner
-    failures = DjangoTestSuiteRunner(
+    import django
+    if hasattr(django, 'setup'):
+        django.setup()
+
+    from django.test.utils import get_runner
+    from test_project import settings
+    TestRunner = get_runner(settings)
+
+    failures = TestRunner(
         verbosity=1,
         interactive=True,
         failfast=False).run_tests(['ydcommon'], *test_args)
